==> basket_0.5.0.orig.tar.gz: basket-0.5.0/src/keyboard.h <==
/***************************************************************************
 *   Copyright (C) 2003 by Sbastien Laot                                 *
 *   sebastien.laout@tuxfamily.org                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KEYBOARD_H
#define KEYBOARD_H

/**
  * Methods to know if Shift and / or Ctrl keys are pressed.
  * Depend on X, but neither QT not KDE provide this class / methods.
  * @author Sbastien Laot
  */
namespace Keyboard
{
	void pressedKeys(bool &shiftPressed, bool &controlPressed);
	bool shiftPressed();
	bool controlPressed();
	bool altPressed();
}

#endif // KEYBOARD_H

==> basket_1.0.2.orig.tar.gz: basket-1.0.2/src/keyboard.h <==
/***************************************************************************
 *   Copyright (C) 2003 by Sbastien Laot                                 *
 *   slaout@linux62.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KEYBOARD_H
#define KEYBOARD_H

/**
  * Methods to know if Shift and / or Ctrl keys are pressed.
  * Depend on X, but neither Qt not KDE provide this class / methods.
  * @author Sbastien Laot
  */
namespace Keyboard
{
	void pressedKeys(bool &shiftPressed, bool &controlPressed);
	bool shiftPressed();
	bool controlPressed();
	bool altPressed();
}

#endif // KEYBOARD_H
